CloudCliCommand<O extends OptionDefinition> class
abstract
- Inheritance
-
- Object
- Command<
void> - CloudCliCommand
- Implementers
- AdminCancelPlanCommand
- AdminInviteUserCommand
- AdminListOrbPlansCommand
- AdminListProcuredCommand
- AdminListProjectsCommand
- AdminListUsersCommand
- AdminPlanCommand
- AdminProcurePlanCommand
- AdminProductCommand
- AdminProjectCommand
- AdminProjectDeleteCommand
- AdminProjectStatusCommand
- AdminRedeployCommand
- AdminUpdatePlanCommand
- BuildSecretSetCommand
- BuildSecretsListCommand
- BuildSecretUnsetCommand
- CliUserSettingsCommand
- CloudAdminCommand
- CloudAttachCustomDomainCommand
- CloudAuthCommand
- CloudContextCommand
- CloudContextListCommand
- CloudContextSetCommand
- CloudContextShowCommand
- CloudContextUnsetCommand
- CloudCustomDomainCommand
- CloudDbBackupCommand
- CloudDbBackupCreateCommand
- CloudDbBackupDeleteCommand
- CloudDbBackupListCommand
- CloudDbBackupRestoreCommand
- CloudDbCommand
- CloudDbConnectionDetailsCommand
- CloudDbScheduleCommand
- CloudDbScheduleSetCommand
- CloudDbScheduleShowCommand
- CloudDbScheduleUnsetCommand
- CloudDbUserCommand
- CloudDbUserCreateCommand
- CloudDbUserResetPasswordCommand
- CloudDbWipeCommand
- CloudDeployCommand
- CloudDeploymentsBuildLogCommand
- CloudDeploymentsBuildSecretCommand
- CloudDeploymentsCommand
- CloudDeploymentsListCommand
- CloudDeploymentsShowCommand
- CloudDetachCustomDomainCommand
- CloudLaunchCommand
- CloudListCustomDomainCommand
- CloudLogCommand
- CloudLoginCommand
- CloudLogoutCommand
- CloudMeCommand
- CloudPasswordCommand
- CloudPasswordListCommand
- CloudPasswordSetCommand
- CloudPasswordUnsetCommand
- CloudProjectCommand
- CloudProjectCreateCommand
- CloudProjectDeleteCommand
- CloudProjectLinkCommand
- CloudProjectListCommand
- CloudProjectUserCommand
- CloudRevokeTokenCommand
- CloudStatusCommand
- CloudVariableCommand
- CloudVariableListCommand
- CloudVariableSetCommand
- CloudVariableUnsetCommand
- CloudVerifyCustomDomainRecordCommand
- CreateTokenCommand
- ListAuthSessionsCommand
- ProjectUserInviteCommand
- ProjectUserListCommand
- ProjectUserRevokeCommand
- VersionCommand
Constructors
-
CloudCliCommand({required CommandLogger logger, List<
O> options = const []})
Properties
-
aliases
→ List<
String> -
Alternate names for this command.
no setterinherited
- argParser → ArgParser
-
The argument parser for this command.
no setterinherited
- argResults → ArgResults?
-
The parsed argument results for this command.
no setterinherited
- baseCommand → String
-
The base command name the CLI was invoked under, e.g.
scloud.no setter - category → String
-
The command's category.
no setterinherited
- description → String
-
A description of this command, included in
usage.no setterinherited -
envVariables
→ Map<
String, String> -
The environment variables used for configuration resolution.
finalinherited
- globalConfiguration → GlobalConfiguration
-
Gets the current global configuration.
Valid after the command runner has started running.
no setter
- globalResults → ArgResults?
-
The parsed global argument results.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
Whether or not this command should be hidden from help listings.
no setterinherited
- invocation → String
-
A single-line template for how to invoke this command (e.g.
"pub getpackage").no setterinherited - logger → CommandLogger
-
final
- messageOutput → MessageOutput?
-
no setterinherited
- name → String
-
The name of this command.
no setterinherited
-
options
→ List<
O> -
The option definitions for this command.
finalinherited
-
parent
→ BetterCommand<
OptionDefinition, void> ? -
The command's parent command, if this is a subcommand.
no setterinherited
- requireLogin → bool
-
Whether the command requires the user to be logged in.
The default is true, subclasses can override to false.
final
- runner → CloudCliCommandRunner
-
Gets the command runner CloudCliCommandRunner.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
subcommands
→ Map<
String, Command< void> > -
An unmodifiable view of all sublevel commands of this command.
no setterinherited
-
suggestionAliases
→ List<
String> -
Alternate non-functional names for this command.
no setterinherited
- summary → String
-
A short description of this command, included in
parent'sCommandRunner.usage.no setterinherited - takesArguments → bool
-
Whether or not this command takes positional arguments in addition to
options.
no setterinherited
- usage → String
-
Generates a string displaying usage information for this command.
no setterinherited
- usageExamples → String?
-
Commands can override this getter to add examples to the usage help text.
no setter
-
An optional footer for usage.
no setteroverride
- warnIfBillingOverdue → bool
-
Whether to warn the user if their account is not in good standing.
The default is true, subclasses can override to false.
final
Methods
-
addSubcommand(
Command< void> command) → void -
Adds
Commandas a subcommand of this.inherited -
confirmToContinue(
CommandOutput output, {required String message, bool? defaultValue}) → Future< void> - Confirms with the user whether to continue with the action.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
printUsage(
) → void -
Prints the usage information for this command.
inherited
-
renderCommand<
T extends Object> (CommandOutput output, {required Operation< T> operation, required OutputWidget textOutputUi, OutputWidget? fallbackErrorUi}) → Future<OutputContext> -
resolveConfiguration(
ArgResults? argResults) → Configuration< O> - Resolves the configuration for this command.
-
run(
) → Future< void> - Runs this command. Subclasses should instead override runWithConfig.
-
runWithConfig(
Configuration< O> commandConfig) → Future<void> - Runs this command with prepared configuration (options). Subclasses should override this method.
-
toString(
) → String -
A string representation of this object.
inherited
-
usageException(
String message) → Never -
Throws a
UsageExceptionwithmessage.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- commandDocBaseUrl → const String