An optional footer for usage.
If a subclass overrides this to return a string, it will automatically be added to the end of usage.
@override String? get usageFooter => '''${usageExamples ?? ''} See the full documentation at: $commandDocBaseUrl${_topCommand.name} ''';