build method
Builds this widget using the output context.
The build method is responsbile for building the tree of widgets below this one. It must never invoke the build or render methods of other widgets.
Implementation
@override
OutputWidget build(final OutputContext context) {
return TextErrorOutputWidget(
exception,
message: exception.errors.join('\n'),
hint: exception.hint,
exception: exception.nestedException,
stackTrace: exception.nestedStackTrace,
);
}