command_runner/cloud_cli_command_runner library

Classes

CloudCliCommandRunner
Represents the Serverpod Cloud CLI main command, its global options, and subcommands.
GlobalConfiguration
The current global configuration values for the Serverpod Cloud CLI.

Enums

GlobalOption<V>
The global configuration options for the Serverpod Cloud CLI.

Typedefs

CliRunContext = ({bool analyticsConsent, String apiServerUrl, String? cloudUserId, String? command, List<String> flags})
The resolved context of a CLI run.
OnRunContextResolved = void Function(CliRunContext context)