RevokeTokenCommandOption<V> enum

Inheritance
Available extensions

Values

tokenId → const RevokeTokenCommandOption<String>
const RevokeTokenCommandOption(StringOption(argName: 'token-id', argPos: 0, mandatory: true, helpText: 'The ID of the token to revoke. Can be passed as the first argument.'))

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
option → ConfigOptionBase<V>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RevokeTokenCommandOption>
A constant List of the values in this enum, in order of their declaration.