Auth class abstract
Constructors
- Auth()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createApiToken(
Client cloudApiClient, {required CommandLogger logger, required String baseCommand, DateTime? expiresAt, Duration? expiresAfter}) → Future< void> -
listAuthSessionsOperation(
Client cloudApiClient) → Future< List< AuthTokenInfo> > -
revokeToken(
Client cloudApiClient, {required CommandLogger logger, required String tokenId, required String localStoragePath}) → Future< void>