CreateTokenCommandOption<V> enum

Inheritance
Available extensions

Values

expireAt → const CreateTokenCommandOption<DateTime>
const CreateTokenCommandOption(DateTimeOption(argName: 'expire-at', helpText: 'The calendar time to expire the token at.'))
idleTtl → const CreateTokenCommandOption<Duration>
const CreateTokenCommandOption(DurationOption(argName: 'idle-ttl', helpText: 'The duration of non-use after which the token will expire.', defaultsTo: Duration(days: 30), group: _expir…
noExpiresAfter → const CreateTokenCommandOption<bool>
const CreateTokenCommandOption(FlagOption(argName: 'no-idle-ttl', helpText: 'Do not expire the token after a duration of non-use.', defaultsTo: false, negatable: false, group: _expires…

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
option → ConfigOptionBase<V>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CreateTokenCommandOption>
A constant List of the values in this enum, in order of their declaration.