LogoutCommandOption<V> enum

Inheritance
Available extensions

Values

tokenId → const LogoutCommandOption<List<String>>
const LogoutCommandOption(MultiStringOption(argName: 'token-id', helpText: 'The token IDs to log out. Logs out the current session if not provided.', defaultsTo: [], group: _sessions))
all → const LogoutCommandOption<bool>
const LogoutCommandOption(FlagOption(argName: 'all', helpText: 'Log out from all sessions including API tokens.', defaultsTo: false, negatable: false, group: _sessions))

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
option → ConfigOptionBase<V>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LogoutCommandOption>
A constant List of the values in this enum, in order of their declaration.