DbBackupCreateOption<V> enum

Inheritance
Available extensions

Values

projectId → const DbBackupCreateOption<String>
const DbBackupCreateOption(ProjectIdOption())
name → const DbBackupCreateOption<String>
const DbBackupCreateOption(StringOption(argName: 'name', helpText: 'An optional name for the snapshot.'))
expireIn → const DbBackupCreateOption<Duration>
const DbBackupCreateOption(DurationOption(argName: 'expire-in', helpText: 'How long to keep the snapshot before it is automatically deleted ' '(e.g. "7d", "24h"…
utc → const DbBackupCreateOption<bool>
const DbBackupCreateOption(_BackupOptions.utc)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
option → ConfigOptionBase<V>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DbBackupCreateOption>
A constant List of the values in this enum, in order of their declaration.