DbScheduleSetOption<V> enum

Inheritance
Available extensions

Values

projectId → const DbScheduleSetOption<String>
const DbScheduleSetOption(ProjectIdOption())
frequency → const DbScheduleSetOption<BackupFrequency>
const DbScheduleSetOption(EnumOption<BackupFrequency>(argName: 'frequency', argAbbrev: 'f', helpText: 'How often a snapshot is taken.', mandatory: true, enumParser: EnumP…
day → const DbScheduleSetOption<int>
const DbScheduleSetOption(IntOption(argName: 'day', helpText: 'The day for a weekly (1-7) or monthly (1-31) schedule. ' 'Defaults to 1. Not applicable to a daily schedule.', mi…
hour → const DbScheduleSetOption<int>
const DbScheduleSetOption(IntOption(argName: 'hour', helpText: 'The hour of the day (0-23) to take the snapshot. Defaults to 0.', min: 0, max: 23))
retention → const DbScheduleSetOption<Duration>
const DbScheduleSetOption(DurationOption(argName: 'retention', helpText: 'How long scheduled snapshots are kept before being automatically ' 'deleted (e.g. "30d"). Uses t…

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
option → ConfigOptionBase<V>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DbScheduleSetOption>
A constant List of the values in this enum, in order of their declaration.