DeployCommandOption<V> enum

Inheritance
Available extensions

Values

projectId → const DeployCommandOption<String>
const DeployCommandOption(ProjectIdOption(asFirstArg: true))
concurrency → const DeployCommandOption<int>
const DeployCommandOption(DeployConcurrencyOption())
dryRun → const DeployCommandOption<bool>
const DeployCommandOption(DeployDryRunOption())
showFiles → const DeployCommandOption<bool>
const DeployCommandOption(DeployShowFilesOption())
output → const DeployCommandOption<File>
const DeployCommandOption(DeployOutputOption())
wait → const DeployCommandOption<bool>
const DeployCommandOption(AwaitOption())
dartVersion → const DeployCommandOption<String>
const DeployCommandOption(DartSdkVersionOption())

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
option → ConfigOptionBase<V>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DeployCommandOption>
A constant List of the values in this enum, in order of their declaration.