DeployConcurrencyOption class

Constructors

DeployConcurrencyOption({OptionGroup? group})
const

Properties

allowedHelp Map<String, String>?
finalinherited
allowedValues List<int>?
finalinherited
argAbbrev String?
finalinherited
argAliases List<String>?
finalinherited
argName String?
finalinherited
argPos int?
finalinherited
configKey String?
finalinherited
customValidator → void Function(int value)?
finalinherited
defaultsTo int?
finalinherited
envName String?
finalinherited
fromCustom int? Function(Configuration<OptionDefinition> cfg)?
finalinherited
fromDefault int Function()?
finalinherited
group → OptionGroup?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
helpText String?
finalinherited
hide bool
finalinherited
mandatory bool
finalinherited
max int?
finalinherited
min int?
finalinherited
option → ConfigOptionBase<int>
Returns self.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
valueHelp String?
finalinherited
valueParser → ValueParser<int>
finalinherited

Methods

defaultValue() int?
inherited
defaultValueString() String?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
qualifiedString() String
inherited
toString() String
A string representation of this object.
inherited
validateDefinition() → void
Validates the configuration option definition.
inherited
validateValue(int value) → void
Validates the parsed value, throwing a FormatException if the value is invalid, or a UsageException if the value is invalid for other reasons.
inherited
valueHelpString() String?
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited