BuildSecretSetCommandConfig<V>
enum
Values
-
projectId
→ const BuildSecretSetCommandConfig<
String> -
const BuildSecretSetCommandConfig(_BuildSecretCommandConfig.projectId) -
name
→ const BuildSecretSetCommandConfig<
String> -
const BuildSecretSetCommandConfig(_BuildSecretCommandConfig.name) -
value
→ const BuildSecretSetCommandConfig<
String> -
const BuildSecretSetCommandConfig(_BuildSecretCommandConfig.value) -
valueFile
→ const BuildSecretSetCommandConfig<
File> -
const BuildSecretSetCommandConfig(_BuildSecretCommandConfig.valueFile) -
buildSecretType
→ const BuildSecretSetCommandConfig<
BuildSecretType> -
const BuildSecretSetCommandConfig(EnumOption<BuildSecretType>(argName: 'type', helpText: 'The type of the build secret.', enumParser: EnumParser(BuildSecretType.values), defaults…
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter -
option
→ ConfigOptionBase<
V> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
BuildSecretSetCommandConfig> - A constant List of the values in this enum, in order of their declaration.