usageExamples property
Commands can override this getter to add examples to the usage help text.
Implementation
@override
String get usageExamples =>
'''\n
Examples
View the build log of the latest deployment.
\$ $baseCommand deployment build-log
View the build log of a specific deployment by sequence number.
\$ $baseCommand deployment build-log 3
View the build log of a specific deployment by UUID.
\$ $baseCommand deployment build-log 550e8400-e29b-41d4-a716-446655440000
''';