usageExamples property

  1. @override
String get usageExamples
override

Commands can override this getter to add examples to the usage help text.

Implementation

@override
String get usageExamples =>
    '''\n
Examples

Show the status of the latest deployment and wait for it to finish.

  \$ $baseCommand deployment show


Show the status of the latest deployment without waiting for it to finish.

  \$ $baseCommand deployment show --no-await


Show the status of a specific deployment by sequence number.

  \$ $baseCommand deployment show 3


Show the status of a specific deployment by UUID.

  \$ $baseCommand deployment show 550e8400-e29b-41d4-a716-446655440000

''';