DeploymentCommands class abstract

Constructors

DeploymentCommands()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fetchBuildLog(Client cloudApiClient, {required CommandLogger logger, required String baseCommand, required String projectId, required bool inUtc, String? deploymentArg}) Future<void>
listBuildSecretsOperation(Client cloudApiClient, {required String projectId}) Future<List<String>>
listDeployAttemptsOperation(Client cloudApiClient, {required String cloudCapsuleId, required int limit}) Future<List<Map<String, Object?>>>
setBuildSecret(Client cloudApiClient, {required CommandLogger logger, required String projectId, required String name, required String value, required BuildSecretType buildSecretType}) Future<void>
showDeployment(Client cloudApiClient, {required CommandLogger logger, required String baseCommand, required String projectId, required bool wait, required bool overallStatus, required bool inUtc, String? deploymentArg}) Future<void>
unsetBuildSecret(Client cloudApiClient, {required CommandLogger logger, required String projectId, required String name}) Future<void>