LaunchOption<V> enum

Inheritance
Available extensions

Values

projectId → const LaunchOption<String>
const LaunchOption(ProjectIdOption.nonMandatory())
preDeployScripts → const LaunchOption<bool>
const LaunchOption(FlagOption(argName: 'pre-deploy-scripts', helpText: 'Set up pre-deploy scripts.', defaultsTo: true))
deploy → const LaunchOption<bool>
const LaunchOption(FlagOption(argName: 'deploy', helpText: 'Automatically deploy the project after setup.', defaultsTo: true, hide: true))
dartVersion → const LaunchOption<String>
const LaunchOption(DartSdkVersionOption())
tui → const LaunchOption<bool>
const LaunchOption(FlagOption(argName: 'tui', defaultsTo: false, helpText: 'Flag to enable interactive terminal UI.', hide: true))
concurrency → const LaunchOption<int>
const LaunchOption(DeployConcurrencyOption(group: _deployGroup))
dryRun → const LaunchOption<bool>
const LaunchOption(DeployDryRunOption(group: _deployGroup))
showFiles → const LaunchOption<bool>
const LaunchOption(DeployShowFilesOption(group: _deployGroup))
output → const LaunchOption<File>
const LaunchOption(DeployOutputOption(group: _deployGroup))
wait → const LaunchOption<bool>
const LaunchOption(AwaitOption(group: _deployGroup))

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
option → ConfigOptionBase<V>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LaunchOption>
A constant List of the values in this enum, in order of their declaration.