Commands can override this getter to add examples to the usage help text.
@override String get usageExamples => '''\n Examples Invite a user to the project \$ $baseCommand project user invite user@example.com ''';