usageExamples property

  1. @override
String? get usageExamples
override

Commands can override this getter to add examples to the usage help text.

Implementation

@override
String? get usageExamples =>
    '''\n
Examples

Set an environment variable called SERVICE_EMAIL to support@example.com.

  \$ $baseCommand variable set SERVICE_EMAIL support@example.com

Set a secret environment variable. The value is encrypted and masked.

  \$ $baseCommand variable set --secret API_KEY sk-...

To set the variable from a file, use the --from-file option.
The full content of the file will be used as the value.

  \$ $baseCommand variable set SERVICE_EMAIL --from-file email.txt
''';