Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
listVariablesOperation(Client cloudApiClient, {required String projectId})
→ Future<List<Map<String, Object?>>>
-
-
setVariable(Client cloudApiClient, {required CommandLogger logger, required String baseCommand, required String projectId, required String name, required String value, bool? secret})
→ Future<void>
-
-
unsetVariable(Client cloudApiClient, {required CommandLogger logger, required String baseCommand, required String projectId, required String name})
→ Future<void>
-