warnIfBillingOverdue property

  1. @override
bool get warnIfBillingOverdue
override

Whether to warn the user if their account is not in good standing. The default is true, subclasses can override to false.

Implementation

@override
bool get warnIfBillingOverdue => false;