fetchCloudUserId static method

String? fetchCloudUserId(
  1. String localStoragePath
)

Returns the id of the cloud user logged in on localStoragePath, or null if the user is not logged in.

Implementation

static String? fetchCloudUserId(final String localStoragePath) {
  final cloudUser = ResourceManager.tryFetchServerpodCloudUserDataSync(
    localStoragePath: localStoragePath,
  );
  return cloudUser?.id;
}