CliUpdateFailedException class

Thrown when installing a new version of the CLI failed.

Implemented types

Constructors

CliUpdateFailedException({required Version version, required String reason})

Properties

hashCode int
The hash code for this object.
no setterinherited
reason String
The technical reason the install failed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version → Version
The version that failed to install.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited