canSelfUpdate property
bool
get
canSelfUpdate
Whether this installation can update itself.
False for a source checkout, which must not be replaced by a pub release.
Implementation
bool get canSelfUpdate;
Whether this installation can update itself.
False for a source checkout, which must not be replaced by a pub release.
bool get canSelfUpdate;