rerun abstract method

Future<int> rerun(
  1. List<String> args, {
  2. required Version installedVersion,
  3. required CommandLogger logger,
})

Reruns the current command with args in a new process.

Returns the exit code of the new process. Throws a ProcessException if the new process could not be started.

Implementation

Future<int> rerun(
  final List<String> args, {
  required final Version installedVersion,
  required final CommandLogger logger,
});