ValueOptionResolution extension

Resolution of the mutually exclusive ValueOption and ValueFileOption pair to the single value they denote.

on
  • Configuration<OptionDefinition>

Methods

valueOrFileContent({required OptionDefinition<String> value, required OptionDefinition<File> valueFile}) String

Available on Configuration<OptionDefinition>, provided by the ValueOptionResolution extension

The value of the value option if it is set, otherwise the full contents of the file given by the valueFile option, decoded as UTF-8.