BillingCommands class abstract

Constructors

BillingCommands()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

warnIfOverdue({required CommandLogger logger, required EndpointBilling billing}) Future<void>
Checks if the owner is in good standing and warns if not.