ProjectFilePreparer class

Constructors

ProjectFilePreparer({required bool isWorkspace, required Directory rootDirectory, required Directory scloudDir, required List<String> includedSubPaths, required List<String> includedPackagePaths, required String projectPackageName, PackageGraph? packageGraph})

Properties

hashCode int
The hash code for this object.
no setterinherited
includedPackagePaths List<String>
final
includedSubPaths List<String>
final
isWorkspace bool
final
packageGraph PackageGraph
The package dependency graph for lockfile filtering.
no setter
projectPackageName String
final
rootDirectory Directory
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scloudDir Directory
final

Methods

filterPubspecLock(String content) String
filterPubspecYaml(String content) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited