scrollRows constant
int
const scrollRows
The number of visual rows the scrolling output section occupies.
Implementation
static const int scrollRows = 5;
The number of visual rows the scrolling output section occupies.
static const int scrollRows = 5;