Launch class abstract

Constructors

Launch()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

confirmSetupAndContinue(CommandLogger logger, ProjectLaunch projectSetup) Future<void>
createProject(CommandLogger logger, {required String consoleServer, required bool openBrowser, required String projectName, required bool usesDb, Duration timeLimit = const Duration(minutes: 5)}) Future<String>
Hands off project creation to the Serverpod Cloud console.
launch(Client cloudApiClient, FileUploaderFactory fileUploaderFactory, {required CommandLogger logger, required Directory projectDirectory, required String? projectId, required bool includePreDeployScripts, required bool performDeploy, required bool tui, required String consoleServer, required bool openBrowser, required int deployConcurrency, required bool deployDryRun, required bool deployShowFiles, String? deployOutputPath, bool deploySkipTailingStatus = false, String? dartVersionOverride}) Future<void>
launchWithoutTui(Client cloudApiClient, FileUploaderFactory fileUploaderFactory, {required CommandLogger logger, required ProjectLaunch projectSetup, required String consoleServer, required bool openBrowser, required int deployConcurrency, required bool deployDryRun, required bool deployShowFiles, String? deployOutputPath, bool deploySkipTailingStatus = false}) Future<void>
launchWithTui(Client cloudApiClient, FileUploaderFactory fileUploaderFactory, {required CommandLogger logger, required ProjectLaunch projectSetup, required String consoleServer, required bool openBrowser, required int deployConcurrency, required bool deployDryRun, required bool deployShowFiles, String? deployOutputPath, bool deploySkipTailingStatus = false}) Future<void>
performLaunch(Client cloudApiClient, FileUploaderFactory fileUploaderFactory, CommandLogger logger, ProjectLaunch projectSetup, {required String consoleServer, required bool openBrowser, required int deployConcurrency, required bool deployDryRun, required bool deployShowFiles, String? deployOutputPath, bool deploySkipTailingStatus = false, IOSink? stdout, IOSink? stderr}) Future<void>
selectProjectId(Client cloudApiClient, CommandLogger logger, ProjectLaunch projectSetup) Future<void>
suggestCodeGenerationPreDeployHook(CommandLogger logger, ProjectLaunch projectSetup) Future<void>
suggestFlutterBuildPreDeployHook(CommandLogger logger, ProjectLaunch projectSetup) Future<void>