ProjectLaunch class
Constructors
-
ProjectLaunch({required Directory projectDir, required TenantProjectPubspec projectPubspec, required bool usesDb, required bool includePreDeployScripts, String? projectId, String? dartVersionOverride, bool? preexistingProject, bool? preexistingProjectDeployed, bool performDeploy = true, List<
String> ? suggestedPreDeployScripts, Map<String, String> ? selectedPasswords})
Properties
- configFilePath ↔ String
-
latefinal
- dartVersionOverride ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- includePreDeployScripts → bool
-
final
- performDeploy → bool
-
final
- preexistingProject ↔ bool?
-
getter/setter pair
- preexistingProjectDeployed ↔ bool?
-
getter/setter pair
- projectDir → Directory
-
final
- projectId ↔ String?
-
getter/setter pair
- projectPubspec → TenantProjectPubspec
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
selectedPasswords
↔ Map<
String, String> -
getter/setter pair
-
suggestedPreDeployScripts
→ List<
String> -
final
- usesDb → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited