activate method

  1. @protected
void activate()
inherited

Called when this State is reinserted into the tree after being removed via deactivate.

In most cases, after a State object has been deactivated, it is not reinserted into the tree, and its dispose method will be called.

In some cases, however, after a State object has been deactivated, the framework will reinsert it into another part of the tree (e.g., if the subtree containing this State object is grafted from one location in the tree to another due to the use of a GlobalKey). If that happens, the framework will call activate to give the State object a chance to reacquire any resources that it released in deactivate.

Implementation

@protected
void activate() {}