reassemble method

  1. @protected
  2. @mustCallSuper
void reassemble()
inherited

Called whenever the application is reassembled during debugging, for example during hot reload.

This provides an opportunity to reinitialize any data that was computed in the initState method or to reset any state.

Implementation

@protected
@mustCallSuper
void reassemble() {}