setState method
Notify the framework that the internal state has changed.
Implementation
@override
void setState(VoidCallback fn) {
if (!mounted) return;
super.setState(fn);
}
Notify the framework that the internal state has changed.
@override
void setState(VoidCallback fn) {
if (!mounted) return;
super.setState(fn);
}