ProjectSelectionOption class

FormConfigOption for a project shown in the project selection screen.

Constructors

ProjectSelectionOption({required String label, String? projectId})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
label String
UI visible label for this option.
final
projectId String?
Null when this represents "Create new project".
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited