alertCopied property
True briefly after the alert's segment is copied, so AlertLine can show
a ✓ Copied confirmation in place of the C Copy hint.
Implementation
bool alertCopied = false;
True briefly after the alert's segment is copied, so AlertLine can show
a ✓ Copied confirmation in place of the C Copy hint.
bool alertCopied = false;