selectedText property

String selectedText
getter/setter pairinherited

The text currently highlighted in a log view, or empty when there is no selection. Updated as the user drags a selection and read when Ctrl-C is pressed so the selection can be copied to the clipboard.

Implementation

String selectedText = '';