ProjectCommands class abstract

Constructors

ProjectCommands()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

checkPlanAvailability(Client cloudApiClient, {required CommandLogger logger, required PlanProfile? plan}) Future<void>
Subcommand to check if the user is subscribed to a given plan, and if not whether the plan can be procured.
createProject(Client cloudApiClient, {required CommandLogger logger, required String projectId, required PlanProfile? plan, required bool enableDb, required String projectDir, required String configFilePath, bool skipConfirmation = false}) Future<void>
Subcommand to create a new tenant project.
deleteProject(Client cloudApiClient, {required CommandLogger logger, required String projectId}) Future<void>
inviteUser(Client cloudApiClient, {required CommandLogger logger, required String projectId, required String email, required List<String> assignRoleNames}) Future<void>
linkProject(Client cloudApiClient, {required CommandLogger logger, required String projectId, required String projectDirectory, required String configFilePath, String? dartVersionOverride}) Future<void>
listProjects(Client cloudApiClient, {required CommandLogger logger, bool showArchived = false}) Future<void>
revokeUser(Client cloudApiClient, {required CommandLogger logger, required String projectId, required String email, List<String> unassignRoleNames = const [], bool unassignAllRoles = false}) Future<void>

Constants

defaultPlan → const String