ScloudSettings class
Constructors
- ScloudSettings({required String localStoragePath})
Properties
-
enableAnalytics
→ Future<
bool?> -
Returns the current setting for enable analytics.
Returns
nullif not set.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
-
projectContext
→ Future<
String?> -
Returns the current global project context.
Returns
nullif not set.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setEnableAnalytics(
bool enableAnalytics) → Future< void> - Sets enable analytics.
-
setProjectContext(
String? projectId) → Future< void> -
Sets the global project context.
Pass
nullto clear it. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited