shared/exceptions/exit_exceptions library

Exceptions / Errors

ErrorExitException
Thrown to indicate that the process shall exit in orderly fashion with an error code.
FailureException
Indicates failure of an operation / command.
UnexpectedErrorExitException
An ErrorExitException caused by an exception that the CLI code did not anticipate.
UserAbortException
Indicates that we are existing with an error code since the user has aborted the operation / command.