UnexpectedErrorExitException class

An ErrorExitException caused by an exception that the CLI code did not anticipate.

Indicates a potential internal error in the CLI or Serverpod Cloud, rather than a failure the user can correct. Errors of this type are eligible for diagnostics reporting.

Inheritance
Implemented types

Constructors

UnexpectedErrorExitException([String? reason, Object? nestedException, StackTrace? nestedStackTrace])

Properties

exitCode int
The exit code to use.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
nestedException Object?
finalinherited
nestedStackTrace StackTrace?
finalinherited
reason String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited