DartSdkSelector class abstract final

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

selectDartSdkVersion({required List<String> supportedSdkMinorVersions, String? commandLineVersion, String? scloudVersion, String? toolVersionsVersion, String? pubspecVersionConstraint, String? lockVersionConstraint}) String
Selects the Dart SDK minor version to build a deployment with, such as 3.13.