util/dart_version_util library

Classes

ProjectDartVersionHint
Optional dartVersion for deploy. It only checks constraint syntax. The GC server will resolve it to a supported dart image tag.
SupportedDartSdkPolicy
The Dart SDK version policy of Serverpod Cloud, as fetched from the server for client-side validation.

Functions

ensureValidVersionConstraint(String value, {String? sourceDescription}) → void
Throws FailureException if value is not a parseable VersionConstraint.
fetchSupportedDartSdkPolicy(Client cloudApiClient, {required CommandLogger logger}) Future<SupportedDartSdkPolicy?>
Fetches the Dart SDK version policy from Serverpod Cloud.