ProjectDartVersionHint class final

Optional dartVersion for deploy. It only checks constraint syntax. The GC server will resolve it to a supported dart image tag.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

normalizeBareMajorMinorOverride(String? value) String?
resolveDartVersionForDeploy({required String? override, required String? configDartSdk, required Iterable<String? Function()> lazyVersionSources}) String?