friendlyFormat method
Formats a duration in a friendly format like "1d 2h 3m 4s 5ms 6us".
Implementation
String friendlyFormat() {
return friendlyFormatDuration(this);
}
Formats a duration in a friendly format like "1d 2h 3m 4s 5ms 6us".
String friendlyFormat() {
return friendlyFormatDuration(this);
}