util/git_metadata library

Classes

GitMetadata
Git repository information collected for a project at deploy time.

Functions

readGitMetadata(String projectDirectory, {GitCommandRunner runGitCommand = _runGitCommand, CommandLogger? logger}) Future<GitMetadata?>
Reads GitMetadata for the git repository containing projectDirectory.

Typedefs

GitCommandRunner = Future<ProcessResult> Function(List<String> arguments, String workingDirectory)
Runs a git subcommand with the given arguments in workingDirectory.