branch property
The name of the currently checked out branch, or null when the
repository is in a detached HEAD state.
Implementation
final String? branch;
The name of the currently checked out branch, or null when the
repository is in a detached HEAD state.
final String? branch;