hasUncommittedChanges property
Whether the working tree has uncommitted changes, including staged, unstaged, and untracked files.
Implementation
final bool hasUncommittedChanges;
Whether the working tree has uncommitted changes, including staged, unstaged, and untracked files.
final bool hasUncommittedChanges;