AnsiStyle enum

Standard ANSI escape code for terminal colors and styles.

Inheritance
Available extensions

Values

terminalDefault → const AnsiStyle
const AnsiStyle('\x1B[39m')
reset → const AnsiStyle
const AnsiStyle('\x1B[0m')
red → const AnsiStyle
const AnsiStyle('\x1B[91m')
yellow → const AnsiStyle
const AnsiStyle('\x1B[33m')
blue → const AnsiStyle
const AnsiStyle('\x1B[34m')
cyan → const AnsiStyle
const AnsiStyle('\x1B[36m')
lightGreen → const AnsiStyle
const AnsiStyle('\x1B[92m')
darkGray → const AnsiStyle
const AnsiStyle('\x1B[90m')
gray → const AnsiStyle
const AnsiStyle('\x1B[2m')
cyanBold → const AnsiStyle
const AnsiStyle('\x1B[1;36m')
bold → const AnsiStyle
const AnsiStyle('\x1B[1m')
italic → const AnsiStyle
const AnsiStyle('\x1B[3m')

Properties

ansiCode String
The ANSI escape code for the style.
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AnsiStyle>
A constant List of the values in this enum, in order of their declaration.