util/inline_tui/src/inline_terminal library

Classes

InlineTerminal
Abstraction over the terminal used by the inline TUI components.
StdioTerminal
A InlineTerminal backed by the process standard input and output.