columns property
int
get
columns
The current width of the terminal in columns, or a sensible default when the width cannot be determined.
Implementation
int get columns;
The current width of the terminal in columns, or a sensible default when the width cannot be determined.
int get columns;