hasTerminal property
bool
get
hasTerminal
Whether the process is attached to an interactive terminal (both input and output).
Implementation
bool get hasTerminal;
Whether the process is attached to an interactive terminal (both input and output).
bool get hasTerminal;