columns property

  1. @override
int get columns
override

The current width of the terminal in columns, or a sensible default when the width cannot be determined.

Implementation

@override
int get columns => _stdout.hasTerminal ? _stdout.terminalColumns : 80;