util/inline_tui/src/tui_key library

Classes

TuiKey
A single key press decoded from terminal input.
TuiKeyDecoder
Decodes raw terminal input bytes into a list of TuiKeys.

Enums

TuiKeyType
The logical type of a key press read from the terminal.