TuiKey class
A single key press decoded from terminal input.
Constructors
- TuiKey(TuiKeyType type, {String? character})
-
Creates a key of the given
typewith an optionalcharacter.const
Properties
- character → String?
-
The printable character, set only when type is TuiKeyType.character.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → TuiKeyType
-
The logical type of this key.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override