util/inline_tui/src/windows_console library

Classes

WindowsConsole
Windows console-mode helpers used to put the console into a raw, virtual-terminal mode.
WindowsConsoleModes
The console input and output modes captured before raw mode was enabled, so they can be restored afterwards.