util/output/command_output library

Classes

CommandOutput
Facade for the output of a command.

Typedefs

Operation<O> = Future<O> Function()
An "operation" function, for the business logic operations of commands that produce some data that is rendered by the command output.