CommandOutput class

Facade for the output of a command.

Constructors

CommandOutput({required OutputFormat format, required CommandLogger logger})

Properties

format OutputFormat
final
hashCode int
The hash code for this object.
no setterinherited
logger CommandLogger
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render<O extends Object>({required Operation<O> operation, required OutputWidget ui}) Future<OutputContext>
renderInteractive<T extends Object?>({required InteractiveWidget<T> ui}) Future<T>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited