ConfirmationWidget class
Renders a yes/no confirmation prompt.
- Inheritance
-
- Object
- OutputWidget
- InteractiveWidget<
bool> - ConfirmationWidget
Constructors
- ConfirmationWidget(String message, {bool? defaultValue})
Properties
Methods
-
build(
OutputContext context) → OutputWidget -
Builds this widget using the output context.
inherited
-
buildTree(
OutputContext context) → WidgetNode -
Builds the tree of widgets below this one.
This is not usually to be overridden by subclasses.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
{required CommandLogger logger}) → void -
Renders this widget using the given IO facade.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited