InteractiveWidget<T> class
Base class for interactive widgets.
Interactive widgets provide a completer that will be completed with the user's response.
Interactive widgets are non-const.
- Inheritance
-
- Object
- OutputWidget
- InteractiveWidget
- Implementers
Constructors
Properties
Methods
-
build(
OutputContext context) → OutputWidget -
Builds this widget using the output context.
inherited
-
buildTree(
OutputContext context) → WidgetNode -
Builds the tree of widgets below this one.
This is not usually to be overridden by subclasses.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
{required CommandLogger logger}) → void -
Renders this widget using the given IO facade.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited