OutputContext class

Context for building OutputWidget UIs. Carries data when building the widget tree.

Constructors

OutputContext(OutputFormat format, [Object? object])
OutputContext.exception(OutputFormat format, Exception exception, StackTrace stackTrace)

Properties

format OutputFormat
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

find<O extends Object>() → O?
get<O extends Object>() → O
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put<O extends Object>(O object) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited