OutputFormatter<O extends Object, D extends Object> class abstract

Base class for output formatters - given an input "object" type O returns a formatted "data" type D.

Implementers

Constructors

OutputFormatter({required bool utc})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
utc bool
final

Methods

format(O object) → D
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited