ValueGetter<O extends Object> typedef

ValueGetter<O extends Object> = Object? Function(O object)

A function that returns the desired value for a given object or for an attribute of that object.

Implementation

typedef ValueGetter<O extends Object> = Object? Function(O object);