objValueFormatter<O extends Object> function
Returns a ValueFormatter function that gets the desired value for an object and applies standard formatting on it, depending on its datatype.
Implementation
ValueFormatter<O> objValueFormatter<O extends Object>({
required final ValueGetter<O> getter,
}) {
return (final O object, {final bool? utc}) {
return _tableCell(getter(object), utc: utc ?? false) ?? '';
};
}