build method

OutputWidget build(
  1. OutputContext context
)

Builds this widget using the output context.

The build method is responsbile for building the tree of widgets below this one. It must never invoke the build or render methods of other widgets.

Implementation

OutputWidget build(final OutputContext context) => this;