WidgetNode class

Constructors

WidgetNode({required OutputWidget widget, required List<WidgetNode> children})

Properties

children List<WidgetNode>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widget OutputWidget
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
renderTree({required CommandLogger logger}) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited