TextTableOutputFormatter<R extends Object> class

Formats a list of row objects into a TextTableData object, needed for FormattedTableWidget.

Composes a list of TableColumnFormatter objects for the columns and their headings.

R is the row object type.

Inheritance

Constructors

TextTableOutputFormatter({required List<TableColumnFormatter<R>> columns, required bool utc})
const

Properties

columns List<TableColumnFormatter<R>>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
utc bool
finalinherited

Methods

format(List<R> objects) TextTableData
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited