TextTableWidget class

Text table rendering widget.

Commands will typically not use this directly, see FormattedTableWidget instead.

Inheritance

Constructors

TextTableWidget(TextTableData content, {List<int?>? columnMinWidths, String? columnSeparator, String? headerDividerColumnSeparator})
const

Properties

columnMinWidths List<int?>?
final
columnSeparator String?
final
content TextTableData
final
hashCode int
The hash code for this object.
no setterinherited
headerDividerColumnSeparator String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(OutputContext context) OutputWidget
Builds this widget using the output context.
inherited
buildTree(OutputContext context) WidgetNode
Builds the tree of widgets below this one. This is not usually to be overridden by subclasses.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render({required CommandLogger logger}) → void
Renders this widget using the given IO facade.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited