PackageGraphFileNotFoundException class

Thrown when '.dart_tool/package_graph.json' is not found.

Implemented types

Constructors

PackageGraphFileNotFoundException(String projectPath)

Properties

hashCode int
The hash code for this object.
no setterinherited
projectPath String
The path to the expected package graph file that was not found. Typically this is '.dart_tool/package_graph.json' under the project directory (where the pubspec.yaml file is located).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited