projectPath property
The path to the expected package graph file that was not found. Typically this is '.dart_tool/package_graph.json' under the project directory (where the pubspec.yaml file is located).
Implementation
final String projectPath;
The path to the expected package graph file that was not found. Typically this is '.dart_tool/package_graph.json' under the project directory (where the pubspec.yaml file is located).
final String projectPath;