PackageGraphParser class final

Parses .dart_tool/package_graph.json into a PackageGraph.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromFile(File file) PackageGraph
Reads and parses a package graph file.
fromJson(Object? json) PackageGraph
Parses a decoded package_graph.json value.
fromProjectDirectory(Directory projectDirectory) PackageGraph
Reads and parses .dart_tool/package_graph.json under projectDirectory.
fromProjectPath(String projectPath) PackageGraph
Reads and parses .dart_tool/package_graph.json under projectPath.