ScrollingCommandOutput class abstract

Constructors

ScrollingCommandOutput()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

runCommand(String command, {required CommandLogger logger, String? heading, String? successMessage, String? failedMessage, int? scrollRows, String? workingDirectory, IOSink? stdoutOverride, IOSink? stderrOverride}) Future<int>
Runs a single command, returning its exit code.

Constants

defaultScrollRows → const int
The number of visual rows the scrolling output section occupies.