defaultScrollRows constant
int
const defaultScrollRows
The number of visual rows the scrolling output section occupies.
Implementation
static const int defaultScrollRows = 5;
The number of visual rows the scrolling output section occupies.
static const int defaultScrollRows = 5;