SplitStreams<K, E> class

Splits a stream into multiple streams based on the classification function. The streams are closed when the last element in the source stream is emitted. If the source stream ends with an error, it is propagated to all streams not yet closed.

Constructors

SplitStreams(Stream<E> source, Iterable<K> keys, K classify(E), bool isLastInSubstream(E))

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getStream(K key) Stream<E>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited