util/upload_description_metadata library

Functions

resolveDartImageTagFromUploadDescription(String uploadDescription) String?
Reads x-goog-meta-dart-version from a Ground Control direct-upload JSON description. Returns null if the Dart image is not found.
resolveHeaderValueFromUploadDescription(String uploadDescription, String headerName) String?
Reads a header value from a Ground Control direct-upload JSON description. Returns null if the header is not found or in an invalid format.
resolveUploadIdFromUploadDescription(String uploadDescription) → UuidValue?
Reads x-goog-meta-upload-id from a Ground Control direct-upload JSON description and converts it to the proper UuidValue. Returns null if the upload ID is not found or in an invalid format.