warnIfBillingOverdue property
Whether to warn the user if their account is not in good standing. The default is true, subclasses can override to false.
Implementation
final bool warnIfBillingOverdue = true;
Whether to warn the user if their account is not in good standing. The default is true, subclasses can override to false.
final bool warnIfBillingOverdue = true;