CliRunContext typedef

CliRunContext = ({bool analyticsConsent, String apiServerUrl, String? cloudUserId, String? command, List<String> flags})

The resolved context of a CLI run.

command is the space-separated command name path including subcommands (e.g. variable set), or null when the run resolved no command. flags holds the names of the flags and options passed on the command line (e.g. ['--project']), without their values. Neither contains option values or positional arguments. cloudUserId is the id of the logged in cloud user, or null when the user is not logged in.

Implementation

typedef CliRunContext = ({
  bool analyticsConsent,
  String? command,
  List<String> flags,
  String apiServerUrl,
  String? cloudUserId,
});