description property

  1. @override
String description
final

A description of this command, included in usage.

Implementation

@override
final description =
    'Manage the global project context.\n'
    '\n'
    'The global project context is a locally stored setting that selects '
    'the project to use when it is not specified by other means. '
    'Commands that act on a project use it as a last resort, '
    'after command line arguments, environment variables, '
    'and the scloud.yaml project configuration file.';