description property
A description of this command, included in usage.
Implementation
@override
final description = '''
Common command to launch and deploy Serverpod Cloud projects.
If there already is a Serverpod Cloud project near the current directory
it will redeploy the project (upload, build, and rollout in the cloud).
Otherwise it will guide you through setting up a new Serverpod Cloud project.
''';