CliRunContextResolver class abstract final

Resolves the parts of the context of a CLI run that are reported as telemetry.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

commandFlags(ArgResults topLevelResults) List<String>
Returns the sorted long names of the flags and options that were passed on the command line, on the top level command and its subcommands (e.g. ['--config-dir', '--project']).
commandPath(ArgResults topLevelResults) String?
Returns the space-separated command name path of the command to run, including its subcommands (e.g. variable set).
fetchCloudUserId(String localStoragePath) String?
Returns the id of the cloud user logged in on localStoragePath, or null if the user is not logged in.