Installs a newer version of the CLI and reruns the current command with it.
- Implementers
Properties
- canSelfUpdate → bool
-
Whether this installation can update itself.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
install(
Version version, {required CommandLogger logger}) → Future< void> -
Installs exactly
versionof the CLI. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rerun(
List< String> args, {required Version installedVersion, required CommandLogger logger}) → Future<int> -
Reruns the current command with
argsin a new process. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited