DartCliUpdater class
A CliUpdater that installs the CLI from pub with the Dart SDK.
Installs with the dart executable from the path, since the running
executable is the CLI itself when it was installed with dart install.
Reruns with the executable that rerunInvocation resolves.
- Implemented types
Constructors
- DartCliUpdater()
-
const
Properties
- canSelfUpdate → bool
-
Whether this installation can update itself.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- installation → CliInstallation
-
The installation the running CLI belongs to.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
install(
Version version, {required CommandLogger logger}) → Future< void> -
Installs exactly
versionof the CLI.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rerun(
List< String> args, {required Version installedVersion, required CommandLogger logger}) → Future<int> -
Reruns the current command with
argsin a new process.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited