DbBackupCommands class abstract
Commands for managing database backup snapshots and the automated backup schedule of a project's database.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createSnapshot(
Client cloudApiClient, {required CommandLogger logger, required String projectId, String? name, Duration? expireIn, bool utc = false}) → Future< void> - Creates a manual snapshot of the project's database.
-
deleteSnapshot(
Client cloudApiClient, {required CommandLogger logger, required String projectId, required String snapshotId, bool skipConfirmation = false}) → Future< void> - Deletes a single snapshot of the project's database.
-
disableSchedule(
Client cloudApiClient, {required CommandLogger logger, required String projectId}) → Future< void> - Disables the automated backup schedule for the project's database.
-
listSnapshots(
Client cloudApiClient, {required CommandLogger logger, required String projectId, bool utc = false}) → Future< void> - Lists all snapshots of the project's database.
-
restoreSnapshot(
Client cloudApiClient, {required CommandLogger logger, required String projectId, required String snapshotId, bool skipConfirmation = false}) → Future< void> - Restores the project's live database to a snapshot.
-
setSchedule(
Client cloudApiClient, {required CommandLogger logger, required String projectId, required BackupFrequency frequency, int? day, int? hour, Duration? retention}) → Future< void> - Sets (creates or updates) the automated backup schedule for the project's database.
-
showSchedule(
Client cloudApiClient, {required CommandLogger logger, required String projectId}) → Future< void> - Shows the automated backup schedule for the project's database.