ScloudLaunchAppState class
Methods
-
activate()
→ void
-
Called when this State is reinserted into the tree after being removed
via
deactivate.
inherited
-
build(BuildContext context)
→ Component
-
Describes the part of the user interface represented by this component.
inherited
-
buildApp(BuildContext context)
→ Component
-
Describes the part of the user interface represented by this component.
-
deactivate()
→ void
-
Called when this State is temporarily removed from the tree.
inherited
-
didChangeDependencies()
→ void
-
Called when dependencies of this object change.
inherited
-
didUpdateComponent(covariant ScloudLaunchApp oldComponent)
→ void
-
Called whenever the component configuration changes.
inherited
-
dismissAlert()
→ void
-
inherited
-
dispose()
→ void
-
Clean up resources. Called when the State object is removed permanently.
-
initState()
→ void
-
Initialize state. Called once when the State object is created.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
onExit()
→ void
-
Called when a second Ctrl-C confirms exit.
inherited
-
reassemble()
→ void
-
Called whenever the application is reassembled during debugging, for
example during hot reload.
inherited
-
rebuild()
→ void
-
inherited
-
setState(VoidCallback fn)
→ void
-
Notify the framework that the internal state has changed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited