deactivate method
- @protected
inherited
Called when this State is temporarily removed from the tree.
The framework calls this method when this State object is removed from
the tree temporarily. It may be reinserted into another part of the tree
(e.g., if the subtree containing this State object is grafted from one
location to another due to the use of a GlobalKey).
If the State is reinserted into the tree, activate will be called.
Otherwise, dispose will be called.
Subclasses should override this method to release any resources that will
be reallocated if the State is reactivated (via activate).
Implementation
@protected
void deactivate() {}