ProjectIdInputConfig class
FormInputConfig for the project ID.
When selectionConfig is provided, the input is shown only when the
"Create new project" option is selected. When null, the input is always
visible (no existing projects to choose from).
Constructors
- ProjectIdInputConfig(ProjectSelectionConfig? selectionConfig)
Properties
- description → FormDescription?
-
Optional description for this config.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String
-
UI visible label for this config.
final
- maxLines → int
-
Max lines allowed for the text input in the UI.
final
-
requirements
→ List<
FormRequirement< FormConfigOption> > -
Requirements for other related configs that must be satisfied
for this config to be enabled.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suffixText → String?
-
Optional suffix text displayed after the input value.
final
- width → double
-
Width of text input in the UI.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited