ProjectSelectionConfig class
FormSelectionConfig for project selection.
Constructors
-
ProjectSelectionConfig({required List<
String> existingProjectIds})
Properties
-
defaultOptions
→ Set<
ProjectSelectionOption> -
The default config options.
final
- description → FormDescription?
-
Optional description for this config.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String
-
UI visible label for this config.
final
- multiSelect → bool
-
Whether this config supports multi-select options.
final
-
options
→ List<
ProjectSelectionOption> -
Supported config options.
final
-
requirements
→ List<
FormRequirement< FormConfigOption> > -
Requirements for other related configs that must be satisfied
for this config to be enabled.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited