ScloudLaunchSelectionConfig<T extends FormConfigOption>
enum
Form selection configuration for ScloudLaunchApp.
Values
-
plan
→ const ScloudLaunchSelectionConfig<
PlanFormConfigOption> -
const ScloudLaunchSelectionConfig<PlanFormConfigOption>(label: 'Plan', options: PlanFormConfigOption.values, defaultOptions: {PlanFormConfigOption.starter}) -
database
→ const ScloudLaunchSelectionConfig<
BoolFormConfigOption> -
const ScloudLaunchSelectionConfig<BoolFormConfigOption>(label: 'Database', options: BoolFormConfigOption.values, defaultOptions: {BoolFormConfigOption.enabled}) -
codegen
→ const ScloudLaunchSelectionConfig<
BoolFormConfigOption> -
const ScloudLaunchSelectionConfig<BoolFormConfigOption>(label: 'Code generation (`serverpod generate`) as a pre-deploy hook', options: BoolFormConfigOption.values, defaultOptions: {BoolF… -
flutterBuild
→ const ScloudLaunchSelectionConfig<
BoolFormConfigOption> -
const ScloudLaunchSelectionConfig<BoolFormConfigOption>(label: 'Flutter build (`serverpod run flutter_build`) as a pre-deploy hook', options: BoolFormConfigOption.values, defaultOptions:…
Properties
-
defaultOptions
→ Set<
T> -
The default config options.
final
- description → FormDescription?
-
Optional description for this config.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- label → String
-
UI visible label for this config.
final
- multiSelect → bool
-
Whether this config supports multi-select options.
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter -
options
→ List<
T> -
Supported config options.
final
-
requirements
→ List<
FormRequirement< FormConfigOption> > -
Requirements for other related configs that must be satisfied
for this config to be enabled.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ScloudLaunchSelectionConfig< FormConfigOption> > - A constant List of the values in this enum, in order of their declaration.