ResourceManager class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- localCloudStorageDirectory → Directory
-
The directory where Serverpod Cloud CLI stores its local data.
no setter
- uniqueUserId → String
-
Gets a persistent, anonymous id for the current user.
This method is copied from serverpod CLI.
no setter
Static Methods
-
removeServerpodCloudAuthData(
{required String localStoragePath}) → Future< void> - Removes Serverpod Cloud authentication and user data from local storage.
-
storeLatestCliVersion(
{required CommandLogger logger, required PackageVersionData cliVersionData, String? localStoragePath}) → Future< void> -
storeServerpodCloudAuthData(
{required ServerpodCloudAuthData authData, required String localStoragePath}) → Future< void> - Stores Serverpod Cloud authentication data to local storage.
-
storeServerpodCloudUserData(
{required ServerpodCloudUserData cloudUserData, required String localStoragePath}) → Future< void> - Stores Serverpod Cloud user data to local storage.
-
storeSettings(
{required ServerpodCloudSettingsData settings, required String localStoragePath}) → Future< void> - Stores Serverpod Cloud settings data to local storage.
-
tryFetchLatestCliVersion(
{String? localStoragePath, required CommandLogger logger}) → Future< PackageVersionData?> -
tryFetchServerpodCloudAuthData(
{required String localStoragePath, required CommandLogger logger}) → Future< ServerpodCloudAuthData?> -
tryFetchServerpodCloudUserDataSync(
{required String localStoragePath}) → ServerpodCloudUserData? -
tryLoadSettings(
{required String localStoragePath}) → Future< ServerpodCloudSettingsData?> - Loads Serverpod Cloud settings data from local storage.