GitMetadata class
Git repository information collected for a project at deploy time.
Constructors
- GitMetadata({required String? commitHash, required String? commitMessage, required String? branch, required bool hasUncommittedChanges})
-
const
Properties
- branch → String?
-
The name of the currently checked out branch, or
nullwhen the repository is in a detachedHEADstate.final - commitHash → String?
-
The short commit hash of
HEAD(e.g.8f3c1ab), ornullif the repository has no commits.final - commitMessage → String?
-
The subject line (first line) of the
HEADcommit message, ornullif the repository has no commits.final - hashCode → int
-
The hash code for this object.
no setterinherited
- hasUncommittedChanges → bool
-
Whether the working tree has uncommitted changes, including staged,
unstaged, and untracked files.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited