finish method
Finishes rendering by optionally drawing a final set of lines, then
moving the cursor below the region and restoring the cursor visibility.
Implementation
void finish({final List<String>? lines}) {
if (lines != null) {
render(lines);
}
if (_renderedLineCount > 0) {
_terminal.write('\n');
}
showCursor();
_renderedLineCount = 0;
}