dispose abstract method
Releases any resources held by the terminal.
Individual components clean up after themselves before returning (e.g. by releasing their input subscription), so this only needs to be called once, towards the end of the process, by whoever owns the terminal's lifecycle.
Implementation
Future<void> dispose();