ScrollingProcess class abstract final

Runs a subprocess and tails its combined stdout/stderr inside a ScrollingSection at the bottom of the terminal.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

run(String executable, List<String> arguments, {required InlineTerminal terminal, String? workingDirectory, Map<String, String>? environment, bool includeParentEnvironment = true, bool runInShell = false, int rows = 5, bool dim = true, String? heading, String? successMessage, String? failedMessage, bool captureOutput = false}) Future<ScrollingProcessResult>
Starts executable with arguments and renders its output in a scrolling section of rows visual rows until the process completes.