keep method
Finishes the section, leaving the currently visible lines in place and moving the cursor below them.
If failedMessage is non-null it replaces the heading above the kept
lines; otherwise the heading is left in place. The spinner is replaced with
a failure icon (✗).
When full is true and captureOutput was enabled, the complete captured
output is rendered (untruncated and undimmed) instead of only the last
visible lines, so the full output is visible after a failure.
Implementation
void keep({final bool full = false}) {
if (_finished) return;
_finished = true;
_success = false;
_stopSpinner();
_finishMessage = failedMessage;
_renderer.finish(lines: _buildLines(full: full));
}