WindowsConsoleModes class
The console input and output modes captured before raw mode was enabled, so they can be restored afterwards.
Constructors
- WindowsConsoleModes(int stdinMode, int stdoutMode)
-
Captures the
stdinModeandstdoutModeto restore later.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stdinMode → int
-
The original mode of the console input buffer (STD_INPUT_HANDLE).
final
- stdoutMode → int
-
The original mode of the console screen buffer (STD_OUTPUT_HANDLE).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited