Operation<O> typedef
Operation<O> =
Future<O> Function()
An "operation" function, for the business logic operations of commands that produce some data that is rendered by the command output.
Implementation
typedef Operation<O> = Future<O> Function();