ValueFormatter<O extends Object> typedef
A function that returns a formatted String value for a given object or for an attribute of that object.
Implementation
typedef ValueFormatter<O extends Object> =
String Function(O object, {required bool? utc});