mapValueFormatter<O extends Map<String, Object?> > function
Returns a ValueFormatter function that gets the value for the given key of a Map<String, Object?> and applies standard formatting on it, depending on its datatype.
Implementation
ValueFormatter<O> mapValueFormatter<O extends Map<String, Object?>>({
required final String key,
}) {
return objValueFormatter(getter: (final object) => object[key]);
}