OutputWidget class abstract
Base class for all command output widgets.
- Implementers
- AdminProjectListTextUi
- AdminUserListTextUi
- AuthSessionListTextUi
- CommandHintTextWidget
- CommandWidget
- CommonClientExceptionsWidget
- DeploymentListTextUi
- ErrorOutputWidget
- ErrorWidget
- ExceptionHandlingWidget
- FailureExceptionWidget
- FormatBranchingWidget
- FormattedStringWidget
- FormattedTableWidget
- InfoTextWidget
- InteractiveWidget
- MeTextUi
- NotFoundExceptionWidget
- OutputWidgetList
- PasswordListTextUi
- PasswordSetTextUi
- PasswordUnsetTextUi
- ProcurementDeniedExceptionWidget
- ProductListTextUi
- ProjectListTextUi
- ProjectUserListTextUi
- RawStringWidget
- ServerpodClientUnauthorizedWidget
- StringColumnListWidget
- SuccessTextWidget
- TextTableWidget
- UnauthorizedExceptionWidget
- VariableListTextUi
Constructors
- OutputWidget()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
OutputContext context) → OutputWidget - Builds this widget using the output context.
-
buildTree(
OutputContext context) → WidgetNode - Builds the tree of widgets below this one. This is not usually to be overridden by subclasses.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
{required CommandLogger logger}) → void - Renders this widget using the given IO facade.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited