TableColumnFormatter<R extends Object> class
Formatting of a column, its heading and its cell value formatter.
R is the row object type.
Constructors
-
TableColumnFormatter(String heading, {required ValueFormatter<
R> formatter}) -
const
-
TableColumnFormatter.forElement(String heading, {required ValueGetter<
R> getter})
Properties
-
formatter
→ ValueFormatter<
R> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- heading → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited