ExceptionHandlingWidget<E extends Exception> class
Renders an error widget if the context contains a matching exception. Otherwise it renders the elseWidget if provided.
- Inheritance
-
- Object
- OutputWidget
- ExceptionHandlingWidget
Constructors
- ExceptionHandlingWidget({required OutputWidget errorWidgetMaker(E exception), OutputWidget? elseWidget})
-
const
Properties
- elseWidget → OutputWidget?
-
final
- errorWidgetMaker → OutputWidget Function(E exception)
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
OutputContext context) → OutputWidget -
Builds this widget using the output context.
override
-
buildTree(
OutputContext context) → WidgetNode -
Builds the tree of widgets below this one.
This is not usually to be overridden by subclasses.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
{required CommandLogger logger}) → void -
Renders this widget using the given IO facade.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited