TextErrorOutputWidget class
- Inheritance
-
- Object
- OutputWidget
- ErrorOutputWidget
- TextErrorOutputWidget
Constructors
- TextErrorOutputWidget(Object error, {String? message, String? hint, Exception? exception, StackTrace? stackTrace, bool newParagraph = false})
-
const
Properties
- error → Object
-
finalinherited
- exception → Exception?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hint → String?
-
final
- message → String?
-
final
- newParagraph → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
final
Methods
-
build(
OutputContext context) → OutputWidget -
Builds this widget using the output context.
inherited
-
buildTree(
OutputContext context) → WidgetNode -
Builds the tree of widgets below this one.
This is not usually to be overridden by subclasses.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
{required CommandLogger logger}) → void -
Renders this widget using the given IO facade.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited