PgPackage class final
A package node in a PackageGraph.
Constructors
Properties
-
dependencies
→ List<
PgPackage> -
final
-
devDependencies
→ List<
PgPackage> -
final
-
devReferences
→ List<
PgPackage> -
Packages that list this package as a dev dependency.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
-
references
→ List<
PgPackage> -
Packages that list this package as a regular dependency.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited